@@ -364,7 +364,7 @@ def exec_operation(objhost, operation, isbatch=False, _test_=None):
     global GV_batchvars
     if not operation: return
     objtarget = get_obj_by_title(operation.get('target'), objhost)
-    exec_checkconnection(objtarget, True)
+    exec_checkconnection(objtarget, False)
     if operation.get('executor') and os.path.isfile(operation['executor']):
         scripts = open(operation['executor']).read()
         if scripts:
